@@ -1,7 +1,7 @@
 model.followup.het.ind <- function(prior.type="unif",rank.prob=TRUE){
 if(prior.type=="unif" & rank.prob){
-cat(
-"model{
+modelstring<-"
+model{
  for(i in 1:len){
   y[i]~dbin(p[i],totaln[i])
   cloglog(p[i])<-log(f[i])+log(lambda[i])
@@ -26,12 +26,13 @@ cat(
  for(i in 1:ntrt){
   rank.prob[1:ntrt,i]<-equals(rk[],i)
  }
-}",file="tempmodel.txt")
+}
+"
 }
 
 if(prior.type=="unif" & !rank.prob){
-cat(
-"model{
+modelstring<-"
+model{
  for(i in 1:len){
   y[i]~dbin(p[i],totaln[i])
   cloglog(p[i])<-log(f[i])+log(lambda[i])
@@ -52,12 +53,13 @@ cat(
    logratio[j,k]<-log(ratio[j,k])
   }
  }
-}",file="tempmodel.txt")
+}
+"
 }
 
 if(prior.type=="invgamma" & rank.prob){
-cat(
-"model{
+modelstring<-"
+model{
  for(i in 1:len){
   y[i]~dbin(p[i],totaln[i])
   cloglog(p[i])<-log(f[i])+log(lambda[i])
@@ -83,12 +85,13 @@ cat(
  for(i in 1:ntrt){
   rank.prob[1:ntrt,i]<-equals(rk[],i)
  }
-}",file="tempmodel.txt")
+}
+"
 }
 
 if(prior.type=="invgamma" & !rank.prob){
-cat(
-"model{
+modelstring<-"
+model{
  for(i in 1:len){
   y[i]~dbin(p[i],totaln[i])
   cloglog(p[i])<-log(f[i])+log(lambda[i])
@@ -110,10 +113,13 @@ cat(
    logratio[j,k]<-log(ratio[j,k])
   }
  }
-}",file="tempmodel.txt")
+}
+"
 }
 
 if(!is.element(prior.type,c("unif","invgamma"))){
-  stop("specified prior type are wrong.")
+  stop("specified prior type is wrong.")
 }
+
+return(modelstring)
 }
\ No newline at end of file
