@@ -1,5 +1,5 @@
 nma.ab.followup <-
-function(s.id,t.id,event.n,total.n,followup,data,trtname,param=c("lograte","logratio","rank.prob"),model="het_cor",prior.type,a=0.001,b=0.001,c=10,higher.better=FALSE,digits=4,n.adapt=5000,n.iter=100000,n.burnin=floor(n.iter/2),n.chains=3,n.thin=max(1,floor((n.iter-n.burnin)/100000)),conv.diag=FALSE,trace="",dic=FALSE,postdens=FALSE){
+function(s.id,t.id,event.n,total.n,followup,data,trtname,param=c("lograte","logratio","rank.prob"),model="het_cor",prior.type,a=0.001,b=0.001,c=10,higher.better=FALSE,digits=4,n.adapt=5000,n.iter=100000,n.burnin=floor(n.iter/2),n.chains=3,n.thin=max(1,floor((n.iter-n.burnin)/100000)),conv.diag=FALSE,trace="",dic=FALSE,postdens=FALSE,mcmc.samples=FALSE){
   ## check the input parameters
   options(warn=1)
   if(missing(s.id)) stop("need to specify study id.")
@@ -42,20 +42,20 @@ function(s.id,t.id,event.n,total.n,followup,data,trtname,param=c("lograte","logr
 
   ## jags model
   if(model=="hom_ind"){
-    model.followup.hom.ind(prior.type,is.element("rank.prob",param))
+    modelstring<-model.followup.hom.ind(prior.type,is.element("rank.prob",param))
   }
   if(model=="het_ind"){
-    model.followup.het.ind(prior.type,is.element("rank.prob",param))
+    modelstring<-model.followup.het.ind(prior.type,is.element("rank.prob",param))
   }
   if(model=="hom_eqcor"){
-    model.followup.hom.eqcor(prior.type,is.element("rank.prob",param))
+    modelstring<-model.followup.hom.eqcor(prior.type,is.element("rank.prob",param))
   }
   if(model=="het_eqcor"){
-    model.followup.het.eqcor(prior.type,is.element("rank.prob",param))
+    modelstring<-model.followup.het.eqcor(prior.type,is.element("rank.prob",param))
   }
   if(model=="het_cor"){
     I <- diag(ntrt)
-    model.followup.het.cor(prior.type,is.element("rank.prob",param))
+    modelstring<-model.followup.het.cor(prior.type,is.element("rank.prob",param))
   }
 
   ## jags data
@@ -168,8 +168,7 @@ function(s.id,t.id,event.n,total.n,followup,data,trtname,param=c("lograte","logr
 
   ## run jags
   cat("start running MCMC...\n")
-  jags.m<-jags.model(file="tempmodel.txt",data=data.jags,inits=init.jags,n.chains=n.chains,n.adapt=n.adapt)
-  unlink("tempmodel.txt")
+  jags.m<-jags.model(file=textConnection(modelstring),data=data.jags,inits=init.jags,n.chains=n.chains,n.adapt=n.adapt)
   update(jags.m,n.iter=n.burnin)
   jags.out<-coda.samples(model=jags.m,variable.names=monitor,n.iter=n.iter,thin=n.thin)
   smry<-summary(jags.out)
@@ -184,7 +183,7 @@ function(s.id,t.id,event.n,total.n,followup,data,trtname,param=c("lograte","logr
   lograte.quan<-array(paste(format(round(smry[lograte.id,"50%"],digits=digits),nsmall=digits)," (",format(round(smry[lograte.id,"2.5%"],digits=digits),nsmall=digits),", ",format(round(smry[lograte.id,"97.5%"],digits=digits),nsmall=digits),")",sep=""),dim=c(ntrt,1))
   colnames(lograte.quan)<-"Median (95% CI)"
   rownames(lograte.quan)<-trtname
-  out$LogHazardRate<-list(Mean_SD=noquote(lograte.stat),Median_CI=noquote(lograte.quan))
+  out$LogRate<-list(Mean_SD=noquote(lograte.stat),Median_CI=noquote(lograte.quan))
 
   if(is.element("rate",param)){
     rate.id<-which(is.element(rownames(smry),paste("rate[",1:ntrt,"]",sep="")))
@@ -194,7 +193,7 @@ function(s.id,t.id,event.n,total.n,followup,data,trtname,param=c("lograte","logr
     rate.quan<-array(paste(format(round(smry[rate.id,"50%"],digits=digits),nsmall=digits)," (",format(round(smry[rate.id,"2.5%"],digits=digits),nsmall=digits),", ",format(round(smry[rate.id,"97.5%"],digits=digits),nsmall=digits),")",sep=""),dim=c(ntrt,1))
     colnames(rate.quan)<-"Median (95% CI)"
     rownames(rate.quan)<-trtname
-    out$HazardRate<-list(Mean_SD=noquote(rate.stat),Median_CI=noquote(rate.quan))
+    out$Rate<-list(Mean_SD=noquote(rate.stat),Median_CI=noquote(rate.quan))
   }
 
   if(is.element("ratio",param)){
@@ -210,7 +209,7 @@ function(s.id,t.id,event.n,total.n,followup,data,trtname,param=c("lograte","logr
         }
       }
     }
-    out$HazardRatio<-list(Mean_SD=noquote(ratio.stat),Median_CI=noquote(ratio.quan))
+    out$RateRatio<-list(Mean_SD=noquote(ratio.stat),Median_CI=noquote(ratio.quan))
   }
 
   if(is.element("logratio",param)){
@@ -228,7 +227,7 @@ function(s.id,t.id,event.n,total.n,followup,data,trtname,param=c("lograte","logr
         }
       }
     }
-    out$LogHazardRatio<-list(Mean_SD=noquote(logratio.stat),Median_CI=noquote(logratio.quan))
+    out$LogRateRatio<-list(Mean_SD=noquote(logratio.stat),Median_CI=noquote(logratio.quan))
   }
 
   if(is.element("rank.prob",param)){
@@ -257,11 +256,15 @@ function(s.id,t.id,event.n,total.n,followup,data,trtname,param=c("lograte","logr
     pen<-sum(dic.out$penalty)
     pen.dev<-dev+pen
     dic.stat<-rbind(dev,pen,pen.dev)
-    rownames(dic.stat)<-c("Mean deviance","Penalty","Penalized deviance")
+    rownames(dic.stat)<-c("D.bar","pD","DIC")
     colnames(dic.stat)<-""
     out$DIC<-dic.stat
   }
 
+  if(mcmc.samples){
+    out$mcmc.samples<-jags.out
+  }
+
   if(!all(trace=="")){
     cat("start saving trace plots...\n")
   }
@@ -272,7 +275,7 @@ function(s.id,t.id,event.n,total.n,followup,data,trtname,param=c("lograte","logr
       par(mfrow=c(n.chains,1))
       for(j in 1:n.chains){
         temp<-as.vector(jags.out[[j]][,paste("rate[",i,"]",sep="")])
-        plot(temp,type="l",col="red",ylab="Hazard Rate",xlab="Iterations",main=paste("Chain",j))
+        plot(temp,type="l",col="red",ylab="Rate",xlab="Iterations",main=paste("Chain",j))
       }
       dev.off()
     }
@@ -283,7 +286,7 @@ function(s.id,t.id,event.n,total.n,followup,data,trtname,param=c("lograte","logr
       par(mfrow=c(n.chains,1))
       for(j in 1:n.chains){
         temp<-as.vector(jags.out[[j]][,paste("lograte[",i,"]",sep="")])
-        plot(temp,type="l",col="red",ylab="Log Hazard Rate",xlab="Iterations",main=paste("Chain",j))
+        plot(temp,type="l",col="red",ylab="Log Rate",xlab="Iterations",main=paste("Chain",j))
       }
       dev.off()
     }
@@ -296,7 +299,7 @@ function(s.id,t.id,event.n,total.n,followup,data,trtname,param=c("lograte","logr
           par(mfrow=c(n.chains,1))
           for(j in 1:n.chains){
             temp<-as.vector(jags.out[[j]][,paste("ratio[",i,",",k,"]",sep="")])
-            plot(temp,type="l",col="red",ylab="Hazard Ratio",xlab="Iterations",main=paste("Chain",j))
+            plot(temp,type="l",col="red",ylab="Rate Ratio",xlab="Iterations",main=paste("Chain",j))
           }
           dev.off()
         }
@@ -311,7 +314,7 @@ function(s.id,t.id,event.n,total.n,followup,data,trtname,param=c("lograte","logr
           par(mfrow=c(n.chains,1))
           for(j in 1:n.chains){
             temp<-as.vector(jags.out[[j]][,paste("logratio[",i,",",k,"]",sep="")])
-            plot(temp,type="l",col="red",ylab="Log Hazard Ratio",xlab="Iterations",main=paste("Chain",j))
+            plot(temp,type="l",col="red",ylab="Log Rate Ratio",xlab="Iterations",main=paste("Chain",j))
           }
           dev.off()
         }
@@ -320,7 +323,7 @@ function(s.id,t.id,event.n,total.n,followup,data,trtname,param=c("lograte","logr
   }
 
   if(postdens){
-    cat("start saving posterior density plot for log hazard rate...\n")
+    cat("start saving posterior density plot for log rate...\n")
     mcmc<-NULL
     dens<-matrix(0,ntrt,3)
     colnames(dens)<-c("ymax","xmin","xmax")
@@ -337,9 +340,9 @@ function(s.id,t.id,event.n,total.n,followup,data,trtname,param=c("lograte","logr
     xmin<-min(dens[,"xmin"])
     xmax<-max(dens[,"xmax"])
     cols<-rainbow(ntrt,s=1,v=0.6)
-    pdf("LogHazardRateDensityPlot.pdf")
+    pdf("LogRateDensityPlot.pdf")
     par(mfrow=c(1,1))
-    plot(density(mcmc[[1]]),xlim=c(xmin,xmax),ylim=c(0,ymax),xlab="Log Hazard Rate",ylab="Density",main="",col=cols[1],lty=1,lwd=2)
+    plot(density(mcmc[[1]]),xlim=c(xmin,xmax),ylim=c(0,ymax),xlab="Log Rate",ylab="Density",main="",col=cols[1],lty=1,lwd=2)
     for(i in 2:ntrt){
       lines(density(mcmc[[i]]),col=cols[i],lty=i,lwd=2)
     }
